==> xlniuxdata_gamepay_new-1.3.6-sources.jar: com/xunlei/gamepay/facade/FacadeImpl.java <==
package com.xunlei.gamepay.facade;

import com.xunlei.common.util.PagedFliper;
import com.xunlei.common.util.Sheet;
import com.xunlei.gamepay.bo.BaseSo;
import com.xunlei.gamepay.bo.BoFactory;
import com.xunlei.gamepay.vo.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;


public class FacadeImpl implements IFacade{

    private BaseSo baseSo;

    public BaseSo getBaseSo() {
        return baseSo;
    }

    public void setBaseSo(BaseSo baseSo) {
        this.baseSo = baseSo;
    }

    private BoFactory boFactory;

	public FacadeImpl() {
	}
	
	public BoFactory getBoFactory() {
		return boFactory;
	}

	public void setBoFactory(BoFactory boFactory) {
		this.boFactory = boFactory;
	}
	@Override
	public void deleteDbConfig(DbConfig data) {
		this.getBoFactory().getDbconfigBo().deleteDbConfig(data);
	}

	@Override
	public void deleteDbConfigByIds(long... ids) {
		this.getBoFactory().getDbconfigBo().deleteDbConfigByIds(ids);
	}

	@Override
	public DbConfig findDbConfig(DbConfig data) {
		return this.getBoFactory().getDbconfigBo().findDbConfig(data);
	}

	@Override
	public Sheet<DbConfig> queryDbConfig(DbConfig data, PagedFliper fliper) {
		return this.getBoFactory().getDbconfigBo().queryDbConfig(data, fliper);
	}

	@Override
	public void saveDbConfig(DbConfig data) {
		this.getBoFactory().getDbconfigBo().saveDbConfig(data);
	}

	@Override
	public void updateDbConfig(DbConfig data) {
		this.getBoFactory().getDbconfigBo().updateDbConfig(data);
	}

	@Override
	public List<DbConfig> queryDbConfigForList(DbConfig data) {
		return this.getBoFactory().getDbconfigBo().queryDbConfigForList(data);
	}

	@Override
	public String getDsName(String gameId, String dbname) {
		DbConfig dbConfig = new DbConfig();
		if(gameId.length()==6){
			gameId = gameId.substring(1,gameId.length());
		}
		dbConfig.setGameid(gameId);
		dbConfig.setDbname(dbname);
		dbConfig = this.findDbConfig(dbConfig);
		if(dbConfig==null){
			return "1";
		}
		return dbConfig.getDsname();
	}

	@Override
	public Sheet<PayDetail> queryPayDetail(PayDetail data, PagedFliper fliper) {
		return this.boFactory.getPaydetailBo().queryPayDetail(data, fliper);
	}

	@Override
	public Sheet<PayDetailOK> queryPayDetailOK(PayDetailOK data,
			PagedFliper fliper) {
		return this.getBoFactory().getPeydetailokBo().queryPayDetailOK(data, fliper);
	}

	@Override
	public PayDetailOK queryPayDetailOKSum(PayDetailOK data) {
		return this.getBoFactory().getPeydetailokBo().queryPayDetailOKSum(data);
	}

	@Override
	public Sheet<ThundercurrencyoutdetailOK> query(
			ThundercurrencyoutdetailOK data, PagedFliper fliper) {
		return this.getBoFactory().getThundercurrencyoutdetailokBo().query(data, fliper);
	}

	@Override
	public ThundercurrencyoutdetailOK querySum(ThundercurrencyoutdetailOK data) {
		return this.getBoFactory().getThundercurrencyoutdetailokBo().querySum(data);
	}

	@Override
	public Sheet<ThundercurrencyoutdetailReq> query(
			ThundercurrencyoutdetailReq data, PagedFliper fliper) {
		return this.getBoFactory().getThundercurrencyoutdetailreqBo().query(data, fliper);
	}

	@Override
	public void updatePayDetailOK(PayDetailOK data) {
		this.getBoFactory().getPeydetailokBo().updatePayDetailOK(data);
	}

	@Override
	public PayDetailOK findPayDetailOK(PayDetailOK data) {
		return this.getBoFactory().getPeydetailokBo().findPayDetailOK(data);
	}

	@Override
	public void insertPayDetailOK(PayDetailOK data) {
		this.getBoFactory().getPeydetailokBo().insertPayDetailOK(data);
	}

	@Override
	public Paydetailokrepair findPaydetailokrepair(Paydetailokrepair data) {
		return this.getBoFactory().getPaydetailokrepairBo().findPaydetailokrepair(data);
	}

	@Override
	public void insertPaydetailokrepair(Paydetailokrepair data) {
		this.getBoFactory().getPaydetailokrepairBo().insertPaydetailokrepair(data);
	}

	@Override
	public Sheet<Paydetailokrepair> queryPaydetailokrepair(
			Paydetailokrepair data, PagedFliper fliper) {
		return this.getBoFactory().getPaydetailokrepairBo().queryPaydetailokrepair(data, fliper);
	}

	@Override
	public void updatePaydetailokrepair(Paydetailokrepair data) {
		this.getBoFactory().getPaydetailokrepairBo().updatePaydetailokrepair(data);
	}

	@Override
	public Sheet<PaydetailokSum> queryPaydetailokSumByUsername(PaydetailokSum data,
			PagedFliper fliper) {
		return this.getBoFactory().getPaydetailokSumBo().queryPaydetailokSumByUsername(data, fliper);
	}

	@Override
	public Sheet<ChargeDayend> queryChargeDayend(ChargeDayend data,
			PagedFliper fliper) {
		return this.getBoFactory().getChargedayendbo().queryChargeDayend(data, fliper);
	}

	@Override
	public ChargeDayend queryChargeDayendForSum(ChargeDayend data) {
		return this.getBoFactory().getChargedayendbo().queryChargeDayendForSum(data);
	}

	@Override
	public Sheet<ChargeMonthEnd> queryChargeMonthEnd(ChargeMonthEnd data,
			PagedFliper fliper) {
		return this.getBoFactory().getChargemonthendbo().queryChargeMonthEnd(data, fliper);
	}

	@Override
	public ChargeMonthEnd queryChargeMonthEndForSum(ChargeMonthEnd data) {
		return this.getBoFactory().getChargemonthendbo().queryChargeMonthEndForSum(data);
	}

	@Override
	public Sheet<PaydetailokSum> exportQueryPaydetailokSumByUsername(
			PaydetailokSum data, PagedFliper fliper) {
		return this.getBoFactory().getPaydetailokSumBo().exportQueryPaydetailokSumByUsername(data, fliper);
	}

    @Override
    public Map<String, BigDecimal> getEachGamePaySum(PayDetailOK data) {
        return this.getBoFactory().getPaydetailokSumBo().getEachGamePaySum(data);
    }

	@Override
	public Sheet<PaydetailokSum> query4GameSum(PaydetailokSum data, PagedFliper fliper) {
		return this.getBoFactory().getPaydetailokSumBo().query4GameSum(data,fliper);
	}

	@Override
	public Sheet<RechargeErrorOrder> queryRechargeErrorOrder(RechargeErrorOrder data,PagedFliper fliper) {
		return this.getBoFactory().getRechargeErrorOrderBo().queryRechargeErrorOrder(data, fliper);
	}

	@Override
	public List<ChargeDayend> queryChargeDayends(ChargeDayend data, String order) {
		return this.getBoFactory().getChargedayendbo().queryChargeDayends(data, order);
	}

    @Override
    public Sheet<ChargeDayend> queryCurMonthSum(ChargeDayend data, PagedFliper fliper){
        return this.getBoFactory().getChargedayendbo().queryCurMonthSum(data, fliper);
    }

	@Override
	public PayDetailOK findMaxPayDetailOK(PayDetailOK data) {
		return findMaxPayDetailOK(data);
	}

	@Override
	public List<Map> getTopRankByGameId(String gameId, String startTime, String endTime, int topNo) {
		return getBoFactory().getPeydetailokBo().getTopRankByGameId(gameId,startTime,endTime,topNo);
	}
}

==> xlniuxdata_gamepay_new-1.3.13-sources.jar: com/xunlei/gamepay/facade/FacadeImpl.java <==
package com.xunlei.gamepay.facade;

import com.xunlei.common.util.PagedFliper;
import com.xunlei.common.util.Sheet;
import com.xunlei.gamepay.bo.BaseSo;
import com.xunlei.gamepay.bo.BoFactory;
import com.xunlei.gamepay.vo.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;


public class FacadeImpl implements IFacade{

    private BaseSo baseSo;

    public BaseSo getBaseSo() {
        return baseSo;
    }

    public void setBaseSo(BaseSo baseSo) {
        this.baseSo = baseSo;
    }

    private BoFactory boFactory;

	public FacadeImpl() {
	}
	
	public BoFactory getBoFactory() {
		return boFactory;
	}

	public void setBoFactory(BoFactory boFactory) {
		this.boFactory = boFactory;
	}
	@Override
	public void deleteDbConfig(DbConfig data) {
		this.getBoFactory().getDbconfigBo().deleteDbConfig(data);
	}

	@Override
	public void deleteDbConfigByIds(long... ids) {
		this.getBoFactory().getDbconfigBo().deleteDbConfigByIds(ids);
	}

	@Override
	public DbConfig findDbConfig(DbConfig data) {
		return this.getBoFactory().getDbconfigBo().findDbConfig(data);
	}

	@Override
	public Sheet<DbConfig> queryDbConfig(DbConfig data, PagedFliper fliper) {
		return this.getBoFactory().getDbconfigBo().queryDbConfig(data, fliper);
	}

	@Override
	public void saveDbConfig(DbConfig data) {
		this.getBoFactory().getDbconfigBo().saveDbConfig(data);
	}

	@Override
	public void updateDbConfig(DbConfig data) {
		this.getBoFactory().getDbconfigBo().updateDbConfig(data);
	}

	@Override
	public List<DbConfig> queryDbConfigForList(DbConfig data) {
		return this.getBoFactory().getDbconfigBo().queryDbConfigForList(data);
	}

	@Override
	public String getDsName(String gameId, String dbname) {
		DbConfig dbConfig = new DbConfig();
		if(gameId.length()==6){
			gameId = gameId.substring(1,gameId.length());
		}
		dbConfig.setGameid(gameId);
		dbConfig.setDbname(dbname);
		dbConfig = this.findDbConfig(dbConfig);
		if(dbConfig==null){
			return "1";
		}
		return dbConfig.getDsname();
	}

	@Override
	public Sheet<PayDetail> queryPayDetail(PayDetail data, PagedFliper fliper) {
		return this.boFactory.getPaydetailBo().queryPayDetail(data, fliper);
	}

	@Override
	public Sheet<PayDetailOK> queryPayDetailOK(PayDetailOK data,
			PagedFliper fliper) {
		return this.getBoFactory().getPeydetailokBo().queryPayDetailOK(data, fliper);
	}

	@Override
	public PayDetailOK queryPayDetailOKSum(PayDetailOK data) {
		return this.getBoFactory().getPeydetailokBo().queryPayDetailOKSum(data);
	}

	@Override
	public Sheet<ThundercurrencyoutdetailOK> query(
			ThundercurrencyoutdetailOK data, PagedFliper fliper) {
		return this.getBoFactory().getThundercurrencyoutdetailokBo().query(data, fliper);
	}

	@Override
	public ThundercurrencyoutdetailOK querySum(ThundercurrencyoutdetailOK data) {
		return this.getBoFactory().getThundercurrencyoutdetailokBo().querySum(data);
	}

	@Override
	public Sheet<ThundercurrencyoutdetailReq> query(
			ThundercurrencyoutdetailReq data, PagedFliper fliper) {
		return this.getBoFactory().getThundercurrencyoutdetailreqBo().query(data, fliper);
	}

	@Override
	public void updatePayDetailOK(PayDetailOK data) {
		this.getBoFactory().getPeydetailokBo().updatePayDetailOK(data);
	}

	@Override
	public PayDetailOK findPayDetailOK(PayDetailOK data) {
		return this.getBoFactory().getPeydetailokBo().findPayDetailOK(data);
	}

	@Override
	public void insertPayDetailOK(PayDetailOK data) {
		this.getBoFactory().getPeydetailokBo().insertPayDetailOK(data);
	}

	@Override
	public Paydetailokrepair findPaydetailokrepair(Paydetailokrepair data) {
		return this.getBoFactory().getPaydetailokrepairBo().findPaydetailokrepair(data);
	}

	@Override
	public void insertPaydetailokrepair(Paydetailokrepair data) {
		this.getBoFactory().getPaydetailokrepairBo().insertPaydetailokrepair(data);
	}

	@Override
	public Sheet<Paydetailokrepair> queryPaydetailokrepair(
			Paydetailokrepair data, PagedFliper fliper) {
		return this.getBoFactory().getPaydetailokrepairBo().queryPaydetailokrepair(data, fliper);
	}

	@Override
	public void updatePaydetailokrepair(Paydetailokrepair data) {
		this.getBoFactory().getPaydetailokrepairBo().updatePaydetailokrepair(data);
	}

	@Override
	public Sheet<PaydetailokSum> queryPaydetailokSumByUsername(PaydetailokSum data,
			PagedFliper fliper) {
		return this.getBoFactory().getPaydetailokSumBo().queryPaydetailokSumByUsername(data, fliper);
	}

	@Override
	public Sheet<ChargeDayend> queryChargeDayend(ChargeDayend data,
			PagedFliper fliper) {
		return this.getBoFactory().getChargedayendbo().queryChargeDayend(data, fliper);
	}

	@Override
	public ChargeDayend queryChargeDayendForSum(ChargeDayend data) {
		return this.getBoFactory().getChargedayendbo().queryChargeDayendForSum(data);
	}

	@Override
	public Sheet<ChargeMonthEnd> queryChargeMonthEnd(ChargeMonthEnd data,
			PagedFliper fliper) {
		return this.getBoFactory().getChargemonthendbo().queryChargeMonthEnd(data, fliper);
	}

	@Override
	public ChargeMonthEnd queryChargeMonthEndForSum(ChargeMonthEnd data) {
		return this.getBoFactory().getChargemonthendbo().queryChargeMonthEndForSum(data);
	}

	@Override
	public Sheet<PaydetailokSum> exportQueryPaydetailokSumByUsername(
			PaydetailokSum data, PagedFliper fliper) {
		return this.getBoFactory().getPaydetailokSumBo().exportQueryPaydetailokSumByUsername(data, fliper);
	}

    @Override
    public Map<String, BigDecimal> getEachGamePaySum(PayDetailOK data) {
        return this.getBoFactory().getPaydetailokSumBo().getEachGamePaySum(data);
    }

	@Override
	public Sheet<PaydetailokSum> query4GameSum(PaydetailokSum data, PagedFliper fliper) {
		return this.getBoFactory().getPaydetailokSumBo().query4GameSum(data,fliper);
	}

	@Override
	public Sheet<RechargeErrorOrder> queryRechargeErrorOrder(RechargeErrorOrder data,PagedFliper fliper) {
		return this.getBoFactory().getRechargeErrorOrderBo().queryRechargeErrorOrder(data, fliper);
	}

	@Override
	public List<ChargeDayend> queryChargeDayends(ChargeDayend data, String order) {
		return this.getBoFactory().getChargedayendbo().queryChargeDayends(data, order);
	}

    @Override
    public Sheet<ChargeDayend> queryCurMonthSum(ChargeDayend data, PagedFliper fliper){
        return this.getBoFactory().getChargedayendbo().queryCurMonthSum(data, fliper);
    }

	@Override
	public PayDetailOK findMaxPayDetailOK(PayDetailOK data) {
		return this.getBoFactory().getPeydetailokBo().findMaxPayDetailOK(data);
	}

	@Override
	public List<Map> getTopRankByGameId(String gameId, String startTime, String endTime, int topNo) {
		return this.getBoFactory().getPeydetailokBo().getTopRankByGameId(gameId,startTime,endTime,topNo);
	}

	@Override
	public List<ThundercurrencyoutdetailDTO> query(
			ThundercurrencyoutdetailDTO data) {
		return this.getBoFactory().getThundercurrencyoutdetailokBo().query(data);
	}

	@Override
	public Sheet<PayDetailOK> queryPayDetailOK(PayDetailOK data, String[] channelIdgameIds, PagedFliper fliper) {
		return this.getBoFactory().getPeydetailokBo().queryPayDetailOK(data, channelIdgameIds, fliper);
	}

	@Override
	public PayDetailOK queryPayDetailOKSum(PayDetailOK data, String[] channelIdgameIds) {
		return this.getBoFactory().getPeydetailokBo().queryPayDetailOKSum(data, channelIdgameIds);
	}
}
